@@ -1,7 +1,7 @@
 //FJSTARTHEADER
 // $Id$
 //
-// Copyright (c) 2005-2024, Matteo Cacciari, Gavin P. Salam and Gregory Soyez
+// Copyright (c) 2005-2025, Matteo Cacciari, Gavin P. Salam and Gregory Soyez
 //
 //----------------------------------------------------------------------
 // This file is part of FastJet.
@@ -177,7 +177,7 @@
 ///
 ///   -cmsiterativecone   switch to the CMSIterativeCone plugin
 ///
-///   -gridjet     switch to the GridJet plugin
+///   -gridjet            switch to the GridJet plugin
 ///
 ///  end of plugins (don't delete this line)
 ///
@@ -354,6 +354,8 @@ int main (int argc, char ** argv) {
   bool   add_dense_coverage = cmdline.present("-dense");
   double ghost_maxrap = cmdline.value("-ghost-maxrap",5.0);
   bool   all_algs = cmdline.present("-all-algs");
+  int    prec = cmdline.int_val("-prec",-1);  
+  if (prec > 0) cout.precision(prec);
   // have the option of comparing the clustering results to those
   // obtained with a different clustering strategy; the misuse the
   // "plugin_strategy" to indicate that no comparison is needed.
